%bcond_with audacious
%bcond_without wlan
%bcond_without rsvg
%bcond_without wayland

Name:           conky
Version:        1.22.0
Release:        %mkrel 1
Summary:        A lightweight system monitor
License:        GPLv3+
Group:          Monitoring
Url:            https://github.com/brndnmtthws/conky
Source0:        https://github.com/brndnmtthws/conky/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  docbook-style-xsl
BuildRequires:  docbook5-style-xsl
BuildRequires:  docbook2x
BuildRequires:  git-core
BuildRequires:  gperf
BuildRequires:  man
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  libxslt-proc
BuildRequires:  libiw-devel
BuildRequires:  lua5.4-devel
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(xcb)

%{?with_wayland:BuildRequires:  wayland-devel wayland-tools pkgconfig(wayland-protocols)}

%{?with_rsvg:BuildRequires:  pkgconfig(librsvg-2.0)}
%{?with_wlan:BuildRequires: wireless-tools}
# There is no audclient beginning with audacious 3.5
# which is our current cauldron one and compilation
# fails. Disable audacious support until it is fixed by upstream.
%{?with_audacious:BuildRequires:        pkgconfig(dbus-glib-1) pkgconfig(audacious)}
BuildRequires:  pkgconfig(alsa)

%description
Conky is a free, light-weight system monitor for X,
that displays any information on your desktop.

%prep
%autosetup -p1

# remove some options from CFLAGS
sed -i 's/\(-Werror\|-Wno-format\|-pedantic\)//g' cmake/ConkyBuildOptions.cmake

# and use our CFLAGS
sed -i '/set(CMAKE_C_FLAGS/,+5d' cmake/ConkyBuildOptions.cmake

# remove executable bits from files included in %{_docdir}
chmod a-x extras/convert.lua

for i in AUTHORS; do
    iconv -f iso8859-1 -t utf8 -o ${i}{_,} && touch -r ${i}{,_} && mv -f ${i}{_,}
done

%build
%cmake \
	-DRELEASE=ON \
        -DMAINTAINER_MODE=ON \
        -DBUILD_BUILTIN_CONFIG=OFF \
        -DBUILD_PORT_MONITORS=OFF \
        -DBUILD_CURL=ON \
        -DBUILD_DOCS=OFF \
        -DBUILD_IBM=OFF \
        -DBUILD_IMLIB2=ON \
        -DBUILD_LUA_CAIRO=ON \
        -DBUILD_LUA_IMLIB2=ON \
        -DBUILD_MOC=OFF \
        -DBUILD_MPD=OFF \
        -DBUILD_NCURSES=OFF \
        -DBUILD_RSS=ON \
        -DBUILD_WEATHER_METAR=ON \
        -DBUILD_WEATHER_XOAP=ON \
        -DBUILD_XDBE=ON \
	-DBUILD_HSV_GRADIENT=0 \
    %{?with_wayland:        -DBUILD_WAYLAND=ON} \
    %{?with_audacious:      -DBUILD_AUDACIOUS=ON} \
    %{?with_wlan:           -DBUILD_WLAN=ON} \
    %{?with_rsvg:           -DBUILD_LUA_RSVG=ON} \
        -DBUILD_PULSEAUDIO=ON \
	-DBUILD_JOURNAL=ON \
	-DBUILD_XINPUT=OFF \
	-DBUILD_LUA_IMLIB2=OFF

%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_sysconfdir}/conky

install -m644 -p data/conky.conf %{buildroot}%{_sysconfdir}/conky
rm -rf %{buildroot}%{_docdir}/conky-*

rm -rf %{buildroot}%{_includedir}/Vc
rm -rf %{buildroot}%{_libdir}/cmake/Vc

%files
%doc AUTHORS README.md extras/*
%license COPYING
%dir %{_sysconfdir}/conky
%config %{_sysconfdir}/conky/conky.conf
%{_bindir}/conky
%{_libdir}/conky/
%{_libdir}/libconky_core.so
%{_datadir}/applications/conky.desktop
%{_iconsdir}/hicolor/scalable/apps/conky-logomark-violet.svg


%changelog
* Wed Jan 22 2025 daviddavid <daviddavid> 1.22.0-1.mga10
+ Revision: 2140569
- new version: 1.22.0

* Thu Nov 14 2024 kekepower <kekepower> 1.21.8-1.mga10
+ Revision: 2115167
- Update to version 1.21.8

* Fri Aug 30 2024 kekepower <kekepower> 1.21.7-1.mga10
+ Revision: 2092213
- Update to version 1.21.7

* Wed Jul 31 2024 kekepower <kekepower> 1.21.6-1.mga10
+ Revision: 2083058
- Update to version 1.21.6

* Wed Jul 24 2024 kekepower <kekepower> 1.21.5-1.mga10
+ Revision: 2082428
- Update to version 1.21.5

* Thu Jul 04 2024 kekepower <kekepower> 1.21.4-1.mga10
+ Revision: 2079743
- Update to version 1.21.4

* Tue Jun 11 2024 kekepower <kekepower> 1.21.3-1.mga10
+ Revision: 2072592
- Update to version 1.21.3

* Sat Jun 01 2024 kekepower <kekepower> 1.21.2-2.mga10
+ Revision: 2069113
- Update Patch0
- Add upstream patch to fix minimum height not being applied

* Thu May 30 2024 kekepower <kekepower> 1.21.2-1.mga10
+ Revision: 2068820
- Add upstream patch to fix build on aarch64
- Update to version 1.21.2
- Update to version 1.21.1

* Tue Feb 27 2024 kekepower <kekepower> 1.19.8-1.mga10
+ Revision: 2044608
- Update to version 1.19.8

* Mon Feb 26 2024 kekepower <kekepower> 1.19.7-1.1.mga10
+ Revision: 2044467
- Update to version 1.19.7

* Fri Oct 13 2023 kekepower <kekepower> 1.19.6-1.mga10
+ Revision: 1996179
- Update to version 1.19.6

* Wed Oct 11 2023 kekepower <kekepower> 1.19.5-1.mga10
+ Revision: 1994666
- Update to version 1.19.5

* Mon Aug 28 2023 kekepower <kekepower> 1.19.4-1.mga10
+ Revision: 1980609
- Update to version 1.19.4

* Wed Apr 12 2023 kekepower <kekepower> 1.19.1-1.mga9
+ Revision: 1952802
- Update to version 1.19.1

* Sun Apr 02 2023 kekepower <kekepower> 1.19.0-1.mga9
+ Revision: 1951237
- Update to version 1.19.0 (from padawan zekemx)

* Mon Mar 06 2023 kekepower <kekepower> 1.18.3-1.mga9
+ Revision: 1947925
- Update to version 1.18.3

* Fri Feb 24 2023 kekepower <kekepower> 1.18.1-1.mga9
+ Revision: 1945222
- Update to version 1.18.1

* Mon Dec 26 2022 kekepower <kekepower> 1.16.1-2.mga9
+ Revision: 1927025
- Build with Wayland support
- Remove unusable Nvidia build settings due to missing library

* Mon Dec 26 2022 kekepower <kekepower> 1.16.1-1.mga9
+ Revision: 1926974
- Update to version 1.16.1

* Sun Dec 25 2022 kekepower <kekepower> 1.16.0-1.mga9
+ Revision: 1926815
- Update to version 1.16.0

* Sun Oct 16 2022 kekepower <kekepower> 1.15.0-1.mga9
+ Revision: 1897139
- Update to version 1.15.0

* Wed Oct 12 2022 kekepower <kekepower> 1.14.0-1.mga9
+ Revision: 1896642
- Don't build docs as they require pandoc to build
- Update to version 1.14.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat May 01 2021 kekepower <kekepower> 1.12.2-1.mga9
+ Revision: 1720711
- Update to version 1.12.2

* Tue Mar 02 2021 kekepower <kekepower> 1.12.1-1.mga9
+ Revision: 1696267
- Update to version 1.12.1

* Fri Jul 31 2020 kekepower <kekepower> 1.11.6-1.mga8
+ Revision: 1610048
- Update to version 1.11.6

* Tue Feb 18 2020 umeabot <umeabot> 1.11.5-3.mga8
+ Revision: 1541394
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Dec 26 2019 shlomif <shlomif> 1.11.5-2.mga8
+ Revision: 1470119
- adapt build for new cmake macros

* Tue Sep 03 2019 shlomif <shlomif> 1.11.5-1.mga8
+ Revision: 1436828
- New version 1.11.5

* Fri Jul 12 2019 shlomif <shlomif> 1.11.4-1.mga8
+ Revision: 1420819
- New version 1.11.4

* Tue Apr 16 2019 kekepower <kekepower> 1.11.3-2.mga7
+ Revision: 1391785
- Remove unneccessary patch

* Tue Apr 16 2019 kekepower <kekepower> 1.11.3-1.mga7
+ Revision: 1391760
- Add hack from Fedora to build debuginfo package
- Add patch to fix libdir
+ shlomif <shlomif>
- New version 1.11.3

* Sun Sep 23 2018 umeabot <umeabot> 1.10.8-2.mga7
+ Revision: 1296765
- Mageia 7 Mass Rebuild

* Sat Feb 24 2018 shlomif <shlomif> 1.10.8-1.mga7
+ Revision: 1204856
- New version 1.10.8

* Sat Jan 27 2018 shlomif <shlomif> 1.10.7-1.mga7
+ Revision: 1197423
- New version 1.10.7 (gentoo).

* Thu Sep 28 2017 cjw <cjw> 1.10.6-2.mga7
+ Revision: 1160777
- fix build with gcc 7

* Sat Jan 14 2017 shlomif <shlomif> 1.10.6-1.mga6
+ Revision: 1081637
- New upstream version 1.10.6.

* Sat Sep 24 2016 shlomif <shlomif> 1.10.4-1.mga6
+ Revision: 1055834
- New version 1.10.4.

* Sat May 28 2016 shlomif <shlomif> 1.10.2-1.mga6
+ Revision: 1019185
- Add missing BR
- New version 1.10.2

* Sun Feb 14 2016 umeabot <umeabot> 1.10.1-3.mga6
+ Revision: 959814
- Mageia 6 Mass Rebuild

* Thu Jan 14 2016 pterjan <pterjan> 1.10.1-2.mga6
+ Revision: 922914
- Disable on ARMv5

* Mon Dec 21 2015 shlomif <shlomif> 1.10.1-1.mga6
+ Revision: 913283
- Add missing BR
- Add missing BR
- Add missing BR
- Add missing BR
- New version 1.10.1 (10x to Fedora for some changes).

* Tue Oct 27 2015 daviddavid <daviddavid> 1.9.0-11.mga6
+ Revision: 895743
- remove empty lang files to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 1.9.0-10.mga5
+ Revision: 748062
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1.9.0-9.mga5
+ Revision: 693669
- Rebuild to fix library dependencies

* Thu Sep 18 2014 luigiwalser <luigiwalser> 1.9.0-8.mga5
+ Revision: 693282
- fix lua BR (should be 5.1)
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild with lua-5.2

* Sat Jun 28 2014 tarakbumba <tarakbumba> 1.9.0-6.mga5
+ Revision: 640565
- Fix BR and alsa support
- Disable audacious support which is currently broken

* Fri Oct 18 2013 umeabot <umeabot> 1.9.0-5.mga4
+ Revision: 521049
- Mageia 4 Mass Rebuild

* Wed Jan 16 2013 cjw <cjw> 1.9.0-4.mga3
+ Revision: 388492
- use lua5.1 because of tolua++

* Fri Jan 11 2013 umeabot <umeabot> 1.9.0-3.mga3
+ Revision: 348114
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 11 2013 fwang <fwang> 1.9.0-2.mga3
+ Revision: 345488
- rebuild for new iw

* Wed Oct 24 2012 fwang <fwang> 1.9.0-1.mga3
+ Revision: 309599
- new version 1.9.0

* Wed Jan 11 2012 doktor5000 <doktor5000> 1.8.1-3.mga2
+ Revision: 194957
- add missing BuildRequires on dbus-glib-1
- fix CVE-2011-3616, privilege escalation vulnerability due to an insecure
  temporary file in Eve Online plugin (fix-race-condidition.patch, from Debian)

* Fri Oct 21 2011 doktor5000 <doktor5000> 1.8.1-2.mga2
+ Revision: 157291
- fix missing curl/types.h compile problem (curl-types.patch)
- added BuildRequires on audacious-devel
- enabled support for the following features:
  o Audacious
  o Weather (METAR)
  o Weather (XOAP)
  o Eve-Online skill monitor
- explicitly enable/disable all features

* Sat Mar 26 2011 kharec <kharec> 1.8.1-1.mga1
+ Revision: 77696
- imported package conky

